@@ -23,13 +23,16 @@
 #include "kconfigtest.h"
 #include "helper.h"
 
-#include <QtTest/QtTest>
+#include "config-kconfig.h"
+
+#include <QtTest>
 #include <qtemporarydir.h>
 #include <QStandardPaths>
 #include <kdesktopfile.h>
 
 #include <ksharedconfig.h>
 #include <kconfiggroup.h>
+#include <kconfigwatcher.h>
 
 #ifdef Q_OS_UNIX
 #include <utime.h>
@@ -43,6 +46,18 @@ KCONFIGGROUP_DECLARE_FLAGS_QOBJECT(KConfigTest, Flags)
 
 QTEST_MAIN(KConfigTest)
 
+Q_DECLARE_METATYPE(KConfigGroup)
+
+static QString homePath()
+{
+#ifdef Q_OS_WIN
+    return QDir::homePath();
+#else
+    // Don't use QDir::homePath() on Unix, it removes any trailing slash, while KConfig uses $HOME.
+    return QString::fromLocal8Bit(qgetenv("HOME"));
+#endif
+}
+
 #define BOOLENTRY1 true
 #define BOOLENTRY2 false
 #define STRINGENTRY1 "hello"
@@ -73,8 +88,8 @@ QTEST_MAIN(KConfigTest)
 #define BYTEARRAYLISTENTRY1 QList<QByteArray>() << "" << "1,2" << "end"
 #define VARIANTLISTENTRY (QVariantList() << true << false << QString("joe") << 10023)
 #define VARIANTLISTENTRY2 (QVariantList() << POINTENTRY << SIZEENTRY)
-#define HOMEPATH QString(QDir::homePath()+"/foo")
-#define HOMEPATHESCAPE QString(QDir::homePath()+"/foo/$HOME")
+#define HOMEPATH QString(homePath()+"/foo")
+#define HOMEPATHESCAPE QString(homePath()+"/foo/$HOME")
 #define DOLLARGROUP "$i"
 
 #define TEST_SUBDIR "kconfigtest_subdir/"
@@ -84,13 +99,14 @@ static inline QString testConfigDir() {
 }
 
 static inline QString kdeGlobalsPath() {
-    return testConfigDir() + "../kdeglobals";
+    return QDir::cleanPath(testConfigDir() + "..") + "/kdeglobals";
 }
 
 void KConfigTest::initTestCase()
 {
     // ensure we don't use files in the real config directory
     QStandardPaths::setTestModeEnabled(true);
+    qRegisterMetaType<KConfigGroup>();
 
     // to make sure all files from a previous failed run are deleted
     cleanupTestCase();
@@ -122,7 +138,7 @@ void KConfigTest::initTestCase()
     cg.writeEntry("stringEntry3", STRINGENTRY3);
     cg.writeEntry("stringEntry4", STRINGENTRY4);
     cg.writeEntry("stringEntry5", STRINGENTRY5);
-    cg.writeEntry("urlEntry1", QUrl("http://qt-project.org"));
+    cg.writeEntry("urlEntry1", QUrl(QStringLiteral("http://qt-project.org")));
     cg.writeEntry("keywith=equalsign", STRINGENTRY1);
     cg.deleteEntry("stringEntry5");
     cg.deleteEntry("stringEntry6");   // deleting a nonexistent entry
@@ -315,7 +331,7 @@ void KConfigTest::testRevertAllEntries()
 void KConfigTest::testSimple()
 {
     // kdeglobals (which was created in initTestCase) must be found this way:
-    const QStringList kdeglobals = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, QLatin1String("kdeglobals"));
+    const QStringList kdeglobals = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, QStringLiteral("kdeglobals"));
     QVERIFY(!kdeglobals.isEmpty());
 
     KConfig sc2(TEST_SUBDIR "kconfigtest");
@@ -343,7 +359,7 @@ void KConfigTest::testSimple()
     QCOMPARE(sc3.readEntry("bytearrayEntry", QByteArray()), BYTEARRAYENTRY);
     QCOMPARE(sc3.readEntry(ESCAPEKEY), QString(ESCAPEENTRY));
     QCOMPARE(sc3.readEntry("Test", QString()), QString::fromUtf8(UTF8BITENTRY));
-    QCOMPARE(sc3.readEntry("emptyEntry"/*, QString("Fietsbel")*/), QString(""));
+    QCOMPARE(sc3.readEntry("emptyEntry"/*, QString("Fietsbel")*/), QLatin1String(""));
     QCOMPARE(sc3.readEntry("emptyEntry", QString("Fietsbel")).isEmpty(), true);
     QCOMPARE(sc3.readEntry("stringEntry1"), QString(STRINGENTRY1));
     QCOMPARE(sc3.readEntry("stringEntry2"), QString(STRINGENTRY2));
@@ -369,8 +385,8 @@ void KConfigTest::testDefaults()
     const QString defaultsFile = TEST_SUBDIR "defaulttest.defaults";
     KConfig defaults(defaultsFile, KConfig::SimpleConfig);
 
-    const QString Default("Default");
-    const QString NotDefault("Not Default");
+    const QString Default(QStringLiteral("Default"));
+    const QString NotDefault(QStringLiteral("Not Default"));
     const QString Value1(STRINGENTRY1);
     const QString Value2(STRINGENTRY2);
 
@@ -419,14 +435,14 @@ void KConfigTest::testLocale()
 
     KConfigGroup group = config.group("Hello");
     group.writeEntry("stringEntry1", Untranslated);
-    config.setLocale("fr");
+    config.setLocale(QStringLiteral("fr"));
     group.writeEntry("stringEntry1", Translated, KConfig::Localized | KConfig::Persistent);
     QVERIFY(config.sync());
 
     QCOMPARE(group.readEntry("stringEntry1", QString()), Translated);
     QCOMPARE(group.readEntryUntranslated("stringEntry1"), Untranslated);
 
-    config.setLocale("C"); // strings written in the "C" locale are written as nonlocalized
+    config.setLocale(QStringLiteral("C")); // strings written in the "C" locale are written as nonlocalized
     group.writeEntry("stringEntry1", Untranslated, KConfig::Localized | KConfig::Persistent);
     QVERIFY(config.sync());
 
@@ -497,6 +513,7 @@ void KConfigTest::testPath()
     QCOMPARE(sc3.readPathEntry("homepathescape", QString()), HOMEPATHESCAPE);
     QCOMPARE(sc3.entryMap()["homepath"], HOMEPATH);
 
+    qputenv("WITHSLASH", "/a/");
     {
         QFile file(testConfigDir() + "/pathtest");
         file.open(QIODevice::WriteOnly | QIODevice::Text);
@@ -505,10 +522,14 @@ void KConfigTest::testPath()
         out << "[Test Group]" << endl
             << "homePath=$HOME/foo" << endl
             << "homePath2=file://$HOME/foo" << endl
+            << "withSlash=$WITHSLASH/foo" << endl
+            << "withSlash2=$WITHSLASH" << endl
             << "withBraces[$e]=file://${HOME}/foo" << endl
             << "URL[$e]=file://${HOME}/foo" << endl
             << "hostname[$e]=$(hostname)" << endl
-            << "noeol=foo"; // no EOL
+            << "escapes=aaa,bb/b,ccc\\,ccc" << endl
+            << "noeol=foo" // no EOL
+            ;
     }
     KConfig cf2(TEST_SUBDIR "pathtest");
     KConfigGroup group = cf2.group("Test Group");
@@ -516,6 +537,10 @@ void KConfigTest::testPath()
     QCOMPARE(group.readPathEntry("homePath", QString()), HOMEPATH);
     QVERIFY(group.hasKey("homePath2"));
     QCOMPARE(group.readPathEntry("homePath2", QString()), QString("file://" + HOMEPATH));
+    QVERIFY(group.hasKey("withSlash"));
+    QCOMPARE(group.readPathEntry("withSlash", QString()), QStringLiteral("/a//foo"));
+    QVERIFY(group.hasKey("withSlash2"));
+    QCOMPARE(group.readPathEntry("withSlash2", QString()), QStringLiteral("/a/"));
     QVERIFY(group.hasKey("withBraces"));
     QCOMPARE(group.readPathEntry("withBraces", QString()), QString("file://" + HOMEPATH));
     QVERIFY(group.hasKey("URL"));
@@ -530,6 +555,9 @@ void KConfigTest::testPath()
 #endif
     QVERIFY(group.hasKey("noeol"));
     QCOMPARE(group.readEntry("noeol", QString()), QString("foo"));
+
+    const auto val = QStringList { QStringLiteral("aaa"), QStringLiteral("bb/b"), QStringLiteral("ccc,ccc")};
+    QCOMPARE(group.readPathEntry("escapes", QStringList()), val);
 }
 
 void KConfigTest::testPersistenceOfExpandFlagForPath()
@@ -664,7 +692,7 @@ void KConfigTest::testInvalid()
 
     // 1 element list
     list << 1;
-    sc3.writeEntry(QString("badList"), list);
+    sc3.writeEntry(QStringLiteral("badList"), list);
 
     QVERIFY(sc3.readEntry("badList", QPoint()) == QPoint());
     QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
@@ -971,7 +999,7 @@ void KConfigTest::testCascadingWithLocale()
     QCOMPARE(group.readEntry("FromGlobal"), QString("true"));
     QCOMPARE(group.readEntry("FromLocal"), QString("true"));
     QCOMPARE(group.readEntry("Name"), QString("Local Testing"));
-    config.setLocale("fr");
+    config.setLocale(QStringLiteral("fr"));
     QCOMPARE(group.readEntry("FromGlobal"), QString("vrai"));
     QCOMPARE(group.readEntry("FromLocal"), QString("vrai"));
     QCOMPARE(group.readEntry("Name"), QString("FR"));
@@ -1063,12 +1091,12 @@ void KConfigTest::testOptionOrder()
             << "entry2[$i][de_DE]=t2" << endl;
     }
     KConfig config(TEST_SUBDIR "doubleattrtest", KConfig::SimpleConfig);
-    config.setLocale("de_DE");
+    config.setLocale(QStringLiteral("de_DE"));
     KConfigGroup cg3 = config.group("group3");
     QVERIFY(!cg3.isImmutable());
     QCOMPARE(cg3.readEntry("entry2", ""), QString("t2"));
     QVERIFY(cg3.isEntryImmutable("entry2"));
-    config.setLocale("C");
+    config.setLocale(QStringLiteral("C"));
     QCOMPARE(cg3.readEntry("entry2", ""), QString("unlocalized"));
     QVERIFY(!cg3.isEntryImmutable("entry2"));
     cg3.writeEntry("entry2", "modified");
@@ -1117,9 +1145,9 @@ void KConfigTest::testSubGroup()
     groupList.sort(); // comes from QSet, so order is undefined
     QCOMPARE(groupList, (QStringList() << "SubGroup/3" << "SubGroup1" << "SubGroup2"));
 
-    const QStringList expectedSubgroup3Keys = (QStringList() << "sub3string");
+    const QStringList expectedSubgroup3Keys = (QStringList() << QStringLiteral("sub3string"));
     QCOMPARE(subcg3.keyList(), expectedSubgroup3Keys);
-    const QStringList expectedParentGroupKeys(QStringList() << "parentgrpstring");
+    const QStringList expectedParentGroupKeys(QStringList() << QStringLiteral("parentgrpstring"));
 
     QCOMPARE(cg.keyList(), expectedParentGroupKeys);
 
@@ -1290,7 +1318,7 @@ void KConfigTest::testConfigCopyTo()
 void KConfigTest::testReparent()
 {
     KConfig cf(TEST_SUBDIR "kconfigtest");
-    const QString name("Enum Types");
+    const QString name(QStringLiteral("Enum Types"));
     KConfigGroup group = cf.group(name);
     const QMap<QString, QString> originalMap = group.entryMap();
     KConfigGroup parent = cf.group("Parent Group");
@@ -1491,7 +1519,7 @@ void KConfigTest::testLocaleConfig()
     // Load the testdata
     QVERIFY(QFile::exists(file));
     KConfig config(file);
-    config.setLocale("ca");
+    config.setLocale(QStringLiteral("ca"));
 
     // This group has only localized values. That is not supported. The values
     // should be dropped on loading.
@@ -1542,7 +1570,7 @@ void KConfigTest::testDeleteWhenLocalized()
     // Load the testdata. We start in locale "ca".
     QVERIFY(QFile::exists(file));
     KConfig config(file);
-    config.setLocale("ca");
+    config.setLocale(QStringLiteral("ca"));
     KConfigGroup cg(&config, "Test4711");
 
     // Delete a value. Once with localized, once with Normal
@@ -1566,7 +1594,7 @@ void KConfigTest::testDeleteWhenLocalized()
     // Now switch the locale to "de" and repeat the checks. Results should be
     // the same. But they currently are not. The localized value are
     // independent of each other. All values are still there in "de".
-    config.setLocale("de");
+    config.setLocale(QStringLiteral("de"));
     QEXPECT_FAIL("", "Currently localized values are not deleted correctly", Continue);
     QVERIFY(!cg.hasKey("foostring"));
     QEXPECT_FAIL("", "Currently localized values are not deleted correctly", Continue);
@@ -1580,7 +1608,7 @@ void KConfigTest::testDeleteWhenLocalized()
 
     // Now switch the locale back "ca" and repeat the checks. Results are
     // again different.
-    config.setLocale("ca");
+    config.setLocale(QStringLiteral("ca"));
     // This line worked above. But now it fails.
     QEXPECT_FAIL("", "Currently localized values are not deleted correctly", Continue);
     QVERIFY(!cg.hasKey("foostring"));
@@ -1610,7 +1638,7 @@ void KConfigTest::testDeleteWhenLocalized()
 
     // Now switch the locale to "de" and repeat the checks. All values
     // still here because only the primary values are deleted.
-    config.setLocale("de");
+    config.setLocale(QStringLiteral("de"));
     QEXPECT_FAIL("", "Currently localized values are not deleted correctly", Continue);
     QVERIFY(!cg.hasKey("foo"));
     QEXPECT_FAIL("", "Currently localized values are not deleted correctly", Continue);
@@ -1628,7 +1656,7 @@ void KConfigTest::testDeleteWhenLocalized()
     // Now switch the locale to "ca" and repeat the checks
     // "foostring" is now really gone because both the primary value and the
     // "ca" value are deleted.
-    config.setLocale("ca");
+    config.setLocale(QStringLiteral("ca"));
     QEXPECT_FAIL("", "Currently localized values are not deleted correctly", Continue);
     QVERIFY(!cg.hasKey("foo"));
     QVERIFY(!cg.hasKey("foostring"));
@@ -1647,13 +1675,13 @@ void KConfigTest::testDeleteWhenLocalized()
 void KConfigTest::testKdeGlobals()
 {
     {
-        KConfig glob("kdeglobals");
+        KConfig glob(QStringLiteral("kdeglobals"));
         KConfigGroup general(&glob, "General");
         general.writeEntry("testKG", "1");
         QVERIFY(glob.sync());
     }
 
-    KConfig globRead("kdeglobals");
+    KConfig globRead(QStringLiteral("kdeglobals"));
     const KConfigGroup general(&globRead, "General");
     QCOMPARE(general.readEntry("testKG"), QString("1"));
 
@@ -1664,7 +1692,7 @@ void KConfigTest::testKdeGlobals()
 
     // Writing using NoGlobals
     {
-        KConfig glob("kdeglobals", KConfig::NoGlobals);
+        KConfig glob(QStringLiteral("kdeglobals"), KConfig::NoGlobals);
         KConfigGroup general(&glob, "General");
         general.writeEntry("testKG", "2");
         QVERIFY(glob.sync());
@@ -1674,7 +1702,7 @@ void KConfigTest::testKdeGlobals()
 
     // Reading using NoGlobals
     {
-        KConfig globReadNoGlob("kdeglobals", KConfig::NoGlobals);
+        KConfig globReadNoGlob(QStringLiteral("kdeglobals"), KConfig::NoGlobals);
         const KConfigGroup generalNoGlob(&globReadNoGlob, "General");
         QCOMPARE(generalNoGlob.readEntry("testKG"), QString("2"));
     }
@@ -1691,12 +1719,41 @@ void KConfigTest::testAnonymousConfig()
     QCOMPARE(general.readEntry("Foo"), QString("Bar"));
 }
 
+void KConfigTest::testQByteArrayUtf8()
+{
+    QTemporaryFile file;
+    QVERIFY(file.open());
+    KConfig config(file.fileName(), KConfig::SimpleConfig);
+    KConfigGroup general(&config, "General");
+    QByteArray bytes(256, '\0');
+    for (int i = 0; i < 256; i++) {
+        bytes[i] = i;
+    }
+    general.writeEntry("Utf8", bytes);
+    config.sync();
+    file.flush();
+    file.close();
+    QFile readFile(file.fileName());
+    QVERIFY(readFile.open(QFile::ReadOnly));
+#define VALUE "Utf8=\\x00\\x01\\x02\\x03\\x04\\x05\\x06\\x07\\x08\\t\\n\\x0b\\x0c\\r\\x0e\\x0f\\x10\\x11\\x12\\x13\\x14\\x15\\x16\\x17\\x18\\x19\\x1a\\x1b\\x1c\\x1d\\x1e\\x1f !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\\x7f\\x80\\x81\\x82\\x83\\x84\\x85\\x86\\x87\\x88\\x89\\x8a\\x8b\\x8c\\x8d\\x8e\\x8f\\x90\\x91\\x92\\x93\\x94\\x95\\x96\\x97\\x98\\x99\\x9a\\x9b\\x9c\\x9d\\x9e\\x9f\\xa0\\xa1\\xa2\\xa3\\xa4\\xa5\\xa6\\xa7\\xa8\\xa9\\xaa\\xab\\xac\\xad\\xae\\xaf\\xb0\\xb1\\xb2\\xb3\\xb4\\xb5\\xb6\\xb7\\xb8\\xb9\\xba\\xbb\\xbc\\xbd\\xbe\\xbf\\xc0\\xc1\\xc2\\xc3\\xc4\\xc5\\xc6\\xc7\\xc8\\xc9\\xca\\xcb\\xcc\\xcd\\xce\\xcf\\xd0\\xd1\\xd2\\xd3\\xd4\\xd5\\xd6\\xd7\\xd8\\xd9\\xda\\xdb\\xdc\\xdd\\xde\\xdf\\xe0\\xe1\\xe2\\xe3\\xe4\\xe5\\xe6\\xe7\\xe8\\xe9\\xea\\xeb\\xec\\xed\\xee\\xef\\xf0\\xf1\\xf2\\xf3\\xf4\\xf5\\xf6\\xf7\\xf8\\xf9\\xfa\\xfb\\xfc\\xfd\\xfe\\xff"
+#ifndef Q_OS_WIN
+    QCOMPARE(readFile.readAll(), QByteArrayLiteral("[General]\n" VALUE "\n"));
+#else
+    QCOMPARE(readFile.readAll(), QByteArrayLiteral("[General]\r\n" VALUE "\r\n"));
+#endif
+#undef VALUE
+
+    // check that reading works
+    KConfig config2(file.fileName(), KConfig::SimpleConfig);
+    KConfigGroup general2(&config2, "General");
+    QCOMPARE(bytes, general2.readEntry("Utf8", QByteArray()));
+}
+
 void KConfigTest::testNewlines()
 {
     // test that kconfig always uses the native line endings
     QTemporaryFile file;
     QVERIFY(file.open());
-    qWarning() << file.fileName();
     KConfig anonConfig(file.fileName(), KConfig::SimpleConfig);
     KConfigGroup general(&anonConfig, "General");
     general.writeEntry("Foo", "Bar");
@@ -1732,7 +1789,7 @@ void KConfigTest::testXdgListEntry()
     KConfig anonConfig(file.fileName(), KConfig::SimpleConfig);
     KConfigGroup grp = anonConfig.group("General");
     QStringList invalidList; // use this as a default when an empty list is expected
-    invalidList << "Error! Default value read!";
+    invalidList << QStringLiteral("Error! Default value read!");
     QCOMPARE(grp.readXdgListEntry("Key1", invalidList), QStringList());
     QCOMPARE(grp.readXdgListEntry("Key2", invalidList), QStringList() << QString());
     QCOMPARE(grp.readXdgListEntry("Key3", invalidList), QStringList() << QString() << QString());
@@ -1763,3 +1820,76 @@ void KConfigTest::testThreads()
         f.waitForFinished();
     }
 }
+
+void KConfigTest::testNotify()
+{
+#if !KCONFIG_USE_DBUS
+        QSKIP("KConfig notification requires DBus");
+#endif
+
+    KConfig config(TEST_SUBDIR "kconfigtest");
+    auto myConfigGroup = KConfigGroup(&config, "TopLevelGroup");
+
+    //mimics a config in another process, which is watching for events
+    auto remoteConfig = KSharedConfig::openConfig(TEST_SUBDIR "kconfigtest");
+    KConfigWatcher::Ptr watcher = KConfigWatcher::create(remoteConfig);
+
+    //some random config that shouldn't be changing when kconfigtest changes, only on kdeglobals
+    auto otherRemoteConfig = KSharedConfig::openConfig(TEST_SUBDIR "kconfigtest2");
+    KConfigWatcher::Ptr otherWatcher = KConfigWatcher::create(otherRemoteConfig);
+
+    QSignalSpy watcherSpy(watcher.data(), &KConfigWatcher::configChanged);
+    QSignalSpy otherWatcherSpy(otherWatcher.data(), &KConfigWatcher::configChanged);
+
+    //write entries in a group and subgroup
+    myConfigGroup.writeEntry("entryA",  "foo", KConfig::Persistent | KConfig::Notify);
+    auto subGroup = myConfigGroup.group("aSubGroup");
+    subGroup.writeEntry("entry1",  "foo", KConfig::Persistent | KConfig::Notify);
+    subGroup.writeEntry("entry2",  "foo", KConfig::Persistent | KConfig::Notify);
+    config.sync();
+    watcherSpy.wait();
+    QCOMPARE(watcherSpy.count(), 2);
+
+    std::sort(watcherSpy.begin(), watcherSpy.end(), [] (QList<QVariant> a, QList<QVariant> b) {
+        return a[0].value<KConfigGroup>().name() <  b[0].value<KConfigGroup>().name();
+    });
+
+    QCOMPARE(watcherSpy[0][0].value<KConfigGroup>().name(), QStringLiteral("TopLevelGroup"));
+    QCOMPARE(watcherSpy[0][1].value<QByteArrayList>(), QByteArrayList({"entryA"}));
+
+    QCOMPARE(watcherSpy[1][0].value<KConfigGroup>().name(), QStringLiteral("aSubGroup"));
+    QCOMPARE(watcherSpy[1][0].value<KConfigGroup>().parent().name(), QStringLiteral("TopLevelGroup"));
+    QCOMPARE(watcherSpy[1][1].value<QByteArrayList>(), QByteArrayList({"entry1", "entry2"}));
+
+   //delete an entry
+    watcherSpy.clear();
+    myConfigGroup.deleteEntry("entryA", KConfig::Persistent | KConfig::Notify);
+    config.sync();
+    watcherSpy.wait();
+    QCOMPARE(watcherSpy.count(), 1);
+    QCOMPARE(watcherSpy[0][0].value<KConfigGroup>().name(), QStringLiteral("TopLevelGroup"));
+    QCOMPARE(watcherSpy[0][1].value<QByteArrayList>(), QByteArrayList({"entryA"}));
+
+    //deleting a group, should notify that every entry in that group has changed
+    watcherSpy.clear();
+    myConfigGroup.deleteGroup("aSubGroup", KConfig::Persistent | KConfig::Notify);
+    config.sync();
+    watcherSpy.wait();
+    QCOMPARE(watcherSpy.count(), 1);
+    QCOMPARE(watcherSpy[0][0].value<KConfigGroup>().name(), QStringLiteral("aSubGroup"));
+    QCOMPARE(watcherSpy[0][1].value<QByteArrayList>(), QByteArrayList({"entry1", "entry2"}));
+
+    //global write still triggers our notification
+    watcherSpy.clear();
+    myConfigGroup.writeEntry("someGlobalEntry",  "foo", KConfig::Persistent | KConfig::Notify | KConfig::Global);
+    config.sync();
+    watcherSpy.wait();
+    QCOMPARE(watcherSpy.count(), 1);
+    QCOMPARE(watcherSpy[0][0].value<KConfigGroup>().name(), QStringLiteral("TopLevelGroup"));
+    QCOMPARE(watcherSpy[0][1].value<QByteArrayList>(), QByteArrayList({"someGlobalEntry"}));
+
+    //watching another file should have only triggered from the kdeglobals change
+    QCOMPARE(otherWatcherSpy.count(), 1);
+    QCOMPARE(otherWatcherSpy[0][0].value<KConfigGroup>().name(), QStringLiteral("TopLevelGroup"));
+    QCOMPARE(otherWatcherSpy[0][1].value<QByteArrayList>(), QByteArrayList({"someGlobalEntry"}));
+}
